@@ -1024,6 +1024,9 @@ contains
       !> Instance of the Hamiltonian specification
       type(ceh_h0spec) :: self
 
+      ! No member variables to initialize
+      self = ceh_h0spec()
+
    end function new_ceh_h0spec
 
 
@@ -1189,8 +1192,6 @@ contains
       !> Polynomial parameters for distant dependent scaleing
       real(wp), intent(out) :: shpoly(:, :)
 
-      integer :: isp, izp, ish
-
       shpoly(:, :) = 0.0_wp
 
    end subroutine get_shpoly
