@@ -14,6 +14,9 @@
 ! You should have received a copy of the GNU Lesser General Public License
 ! along with tblite.  If not, see <https://www.gnu.org/licenses/>.
 
+!> @dir tblite/solvation/data
+!> Provides solvent specific data for parametrized solvation models
+
 !> @file tblite/solvation/data.f90
 !> Provides element specific data
 
@@ -38,6 +41,7 @@ module tblite_solvation_data
       real(wp) :: gamma
       real(wp) :: phi2
       real(wp) :: psi2
+      character(len=:), allocatable :: solvent
    end type solvent_data
 
    interface solvent_data
@@ -239,191 +243,203 @@ pure function get_solvent_data(solvent) result(data)
 
    select case(compact(solvent))
    case default
-      data = solvent_data(-1.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(-1.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, "none")
    case("inf")
-      data = solvent_data(huge(1.0_wp), 1.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(huge(1.0_wp), 1.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, "inf")
    case("2methylpyridine")
-      data = solvent_data(9.9533_wp, 1.4957_wp, 0.0_wp, 0.58_wp, 47.5_wp, 0.509796_wp, 0.0_wp)
+      data = solvent_data(9.9533_wp, 1.4957_wp, 0.0_wp, 0.58_wp, 47.5_wp, 0.509796_wp, 0.0_wp, "2methylpyridine")
    case("4methyl2pentanone")
-      data = solvent_data(12.8871_wp, 1.3962_wp, 0.0_wp, 0.51_wp, 33.83_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(12.8871_wp, 1.3962_wp, 0.0_wp, 0.51_wp, 33.83_wp, 0.0_wp, 0.0_wp, "4methyl2pentanone")
    case("aceticacid")
-      data = solvent_data(6.2528_wp, 1.372_wp, 0.61_wp, 0.44_wp, 39.01_wp, 0.0_wp, 0.0_wp)
-   case("acetonitrile")
-      data = solvent_data(35.6881_wp, 1.3442_wp, 0.07_wp, 0.32_wp, 41.25_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(6.2528_wp, 1.372_wp, 0.61_wp, 0.44_wp, 39.01_wp, 0.0_wp, 0.0_wp, "aceticacid")
+   case("acetone")
+      data = solvent_data(20.493_wp, 1.3588_wp, 0.04_wp, 0.49_wp, 33.77_wp, 0.0_wp, 0.0_wp, "acetone") 
+   case("acetonitrile","mecn")
+      data = solvent_data(35.6881_wp, 1.3442_wp, 0.07_wp, 0.32_wp, 41.25_wp, 0.0_wp, 0.0_wp, "acetonitrile")
    case("acetophenone")
-      data = solvent_data(17.44_wp, 1.5372_wp, 0.0_wp, 0.48_wp, 56.19_wp, 0.444889_wp, 0.0_wp)
+      data = solvent_data(17.44_wp, 1.5372_wp, 0.0_wp, 0.48_wp, 56.19_wp, 0.444889_wp, 0.0_wp, "acetophenone")
    case("aniline")
-      data = solvent_data(6.8882_wp, 1.5863_wp, 0.26_wp, 0.41_wp, 60.62_wp, 0.734449_wp, 0.0_wp)
+      data = solvent_data(6.8882_wp, 1.5863_wp, 0.26_wp, 0.41_wp, 60.62_wp, 0.734449_wp, 0.0_wp, "aniline")
    case("anisole")
-      data = solvent_data(4.2247_wp, 1.5174_wp, 0.0_wp, 0.29_wp, 50.52_wp, 0.5625_wp, 0.0_wp)
+      data = solvent_data(4.2247_wp, 1.5174_wp, 0.0_wp, 0.29_wp, 50.52_wp, 0.5625_wp, 0.0_wp, "anisole")
+   case("benzaldehyde") ! no Minnisota database entry
+      data = solvent_data(17.85_wp,1.5456_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, "benzaldehyde")
    case("benzene")
-      data = solvent_data(2.2706_wp, 1.5011_wp, 0.0_wp, 0.14_wp, 40.62_wp, 1_wp, 0.0_wp)
+      data = solvent_data(2.2706_wp, 1.5011_wp, 0.0_wp, 0.14_wp, 40.62_wp, 1_wp, 0.0_wp, "benzene")
    case("benzonitrile")
-      data = solvent_data(25.592_wp, 1.5289_wp, 0.0_wp, 0.33_wp, 55.83_wp, 0.5625_wp, 0.0_wp)
+      data = solvent_data(25.592_wp, 1.5289_wp, 0.0_wp, 0.33_wp, 55.83_wp, 0.5625_wp, 0.0_wp, "benzonitrile")
    case("benzylalcohol")
-      data = solvent_data(12.4569_wp, 1.5396_wp, 0.33_wp, 0.56_wp, 52.96_wp, 0.5625_wp, 0.0_wp)
+      data = solvent_data(12.4569_wp, 1.5396_wp, 0.33_wp, 0.56_wp, 52.96_wp, 0.5625_wp, 0.0_wp, "benzylalcohol")
    case("bromobenzene")
-      data = solvent_data(5.3954_wp, 1.5597_wp, 0.0_wp, 0.09_wp, 50.72_wp, 0.734449_wp, 0.020449_wp)
+      data = solvent_data(5.3954_wp, 1.5597_wp, 0.0_wp, 0.09_wp, 50.72_wp, 0.734449_wp, 0.020449_wp, "bromobenzene")
    case("bromoethane")
-      data = solvent_data(9.01_wp, 1.4239_wp, 0.0_wp, 0.12_wp, 34_wp, 0.0_wp, 0.110889_wp)
+      data = solvent_data(9.01_wp, 1.4239_wp, 0.0_wp, 0.12_wp, 34_wp, 0.0_wp, 0.110889_wp, "bromoethane")
    case("bromoform")
       data = solvent_data(4.2488_wp, 1.6005_wp, 0.15_wp, 0.06_wp, 64.58_wp, 0.0_wp, 0.5625_wp)
    case("bromooctane")
-      data = solvent_data(5.0244_wp, 1.4524_wp, 0.0_wp, 0.12_wp, 41.28_wp, 0.0_wp, 0.0121_wp)
+      data = solvent_data(5.0244_wp, 1.4524_wp, 0.0_wp, 0.12_wp, 41.28_wp, 0.0_wp, 0.0121_wp, "bromooctane")
    case("butanol")
-      data = solvent_data(17.3323_wp, 1.3993_wp, 0.37_wp, 0.48_wp, 35.88_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(17.3323_wp, 1.3993_wp, 0.37_wp, 0.48_wp, 35.88_wp, 0.0_wp, 0.0_wp, "butanol")
    case("butanone")
-      data = solvent_data(18.2457_wp, 1.3788_wp, 0.0_wp, 0.51_wp, 34.5_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(18.2457_wp, 1.3788_wp, 0.0_wp, 0.51_wp, 34.5_wp, 0.0_wp, 0.0_wp, "butanone")
    case("butylacetate")
-      data = solvent_data(4.9941_wp, 1.3941_wp, 0.0_wp, 0.45_wp, 35.81_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(4.9941_wp, 1.3941_wp, 0.0_wp, 0.45_wp, 35.81_wp, 0.0_wp, 0.0_wp, "butylacetate")
    case("butylbenzene")
-      data = solvent_data(2.36_wp, 1.4898_wp, 0.0_wp, 0.15_wp, 41.33_wp, 0.36_wp, 0.0_wp)
-   case("carbondisulfide")
-      data = solvent_data(2.6105_wp, 1.6319_wp, 0.0_wp, 0.07_wp, 45.45_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(2.36_wp, 1.4898_wp, 0.0_wp, 0.15_wp, 41.33_wp, 0.36_wp, 0.0_wp, "butylbenzene")
+   case("carbondisulfide","cs2")
+      data = solvent_data(2.6105_wp, 1.6319_wp, 0.0_wp, 0.07_wp, 45.45_wp, 0.0_wp, 0.0_wp, "carbondisulfide")
    case("carbontet")
-      data = solvent_data(2.228_wp, 1.4601_wp, 0.0_wp, 0.0_wp, 38.04_wp, 0.0_wp, 0.64_wp)
+      data = solvent_data(2.228_wp, 1.4601_wp, 0.0_wp, 0.0_wp, 38.04_wp, 0.0_wp, 0.64_wp, "carbontet")
    case("chlorobenzene")
-      data = solvent_data(5.6968_wp, 1.5241_wp, 0.0_wp, 0.07_wp, 47.48_wp, 0.734449_wp, 0.020449_wp)
-   case("chloroform")
-      data = solvent_data(4.7113_wp, 1.4459_wp, 0.15_wp, 0.02_wp, 38.39_wp, 0.0_wp, 0.5625_wp)
+      data = solvent_data(5.6968_wp, 1.5241_wp, 0.0_wp, 0.07_wp, 47.48_wp, 0.734449_wp, 0.020449_wp, "chlorobenzene")
+   case("chloroform","chcl3")
+      data = solvent_data(4.7113_wp, 1.4459_wp, 0.15_wp, 0.02_wp, 38.39_wp, 0.0_wp, 0.5625_wp, "chloroform")
    case("chlorohexane")
-      data = solvent_data(5.9491_wp, 1.4199_wp, 0.0_wp, 0.1_wp, 37.03_wp, 0.0_wp, 0.020449_wp)
+      data = solvent_data(5.9491_wp, 1.4199_wp, 0.0_wp, 0.1_wp, 37.03_wp, 0.0_wp, 0.020449_wp, "chlorohexane")
    case("cyclohexane")
-      data = solvent_data(2.0165_wp, 1.4266_wp, 0.0_wp, 0.0_wp, 35.48_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(2.0165_wp, 1.4266_wp, 0.0_wp, 0.0_wp, 35.48_wp, 0.0_wp, 0.0_wp, "cyclohexane")
    case("cyclohexanone")
-      data = solvent_data(15.6186_wp, 1.4507_wp, 0.0_wp, 0.56_wp, 49.76_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(15.6186_wp, 1.4507_wp, 0.0_wp, 0.56_wp, 49.76_wp, 0.0_wp, 0.0_wp, "cyclohexanone")
    case("decalin")
-      data = solvent_data(2.196_wp, 1.4528_wp, 0.0_wp, 0.0_wp, 43.82_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(2.196_wp, 1.4528_wp, 0.0_wp, 0.0_wp, 43.82_wp, 0.0_wp, 0.0_wp, "decalin")
    case("decane")
-      data = solvent_data(1.9846_wp, 1.4102_wp, 0.0_wp, 0.0_wp, 33.64_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(1.9846_wp, 1.4102_wp, 0.0_wp, 0.0_wp, 33.64_wp, 0.0_wp, 0.0_wp, "decane")
    case("decanol")
-      data = solvent_data(7.5305_wp, 1.4372_wp, 0.37_wp, 0.48_wp, 41.04_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(7.5305_wp, 1.4372_wp, 0.37_wp, 0.48_wp, 41.04_wp, 0.0_wp, 0.0_wp, "decanol")
    case("dibromoethane")
-      data = solvent_data(4.9313_wp, 1.5387_wp, 0.1_wp, 0.17_wp, 56.93_wp, 0.0_wp, 0.25_wp)
+      data = solvent_data(4.9313_wp, 1.5387_wp, 0.1_wp, 0.17_wp, 56.93_wp, 0.0_wp, 0.25_wp, "dibromoethane")
    case("dibutylether")
-      data = solvent_data(3.0473_wp, 1.3992_wp, 0.0_wp, 0.45_wp, 35.98_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(3.0473_wp, 1.3992_wp, 0.0_wp, 0.45_wp, 35.98_wp, 0.0_wp, 0.0_wp, "dibutylether")
    case("dichloroethane")
-      data = solvent_data(10.125_wp, 1.4448_wp, 0.1_wp, 0.11_wp, 45.86_wp, 0.0_wp, 0.25_wp)
-   case("diethylether")
-      data = solvent_data(4.24_wp, 1.3526_wp, 0.0_wp, 0.41_wp, 23.96_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(10.125_wp, 1.4448_wp, 0.1_wp, 0.11_wp, 45.86_wp, 0.0_wp, 0.25_wp, "dichloroethane")
+   case("diethylether","ether")
+      data = solvent_data(4.24_wp, 1.3526_wp, 0.0_wp, 0.41_wp, 23.96_wp, 0.0_wp, 0.0_wp, "diethylether")
    case("diisopropylether")
-      data = solvent_data(3.38_wp, 1.3679_wp, 0.0_wp, 0.41_wp, 24.86_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(3.38_wp, 1.3679_wp, 0.0_wp, 0.41_wp, 24.86_wp, 0.0_wp, 0.0_wp, "diisopropylether")
    case("dimethylacetamide")
-      data = solvent_data(37.7807_wp, 1.438_wp, 0.0_wp, 0.78_wp, 47.62_wp, 0.0_wp, 0.0_wp)
-   case("dimethylformamide")
-      data = solvent_data(37.219_wp, 1.4305_wp, 0.0_wp, 0.74_wp, 49.56_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(37.7807_wp, 1.438_wp, 0.0_wp, 0.78_wp, 47.62_wp, 0.0_wp, 0.0_wp, "dimethylacetamide")
+   case("dimethylformamide","dmf")
+      data = solvent_data(37.219_wp, 1.4305_wp, 0.0_wp, 0.74_wp, 49.56_wp, 0.0_wp, 0.0_wp, "dimethylformamide")
    case("dimethylpyridine")
-      data = solvent_data(7.1735_wp, 1.4953_wp, 0.0_wp, 0.63_wp, 44.64_wp, 0.390625_wp, 0.0_wp)
-   case("dimethylsulfoxide")
-      data = solvent_data(46.826_wp, 1.417_wp, 0.0_wp, 0.88_wp, 61.78_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(7.1735_wp, 1.4953_wp, 0.0_wp, 0.63_wp, 44.64_wp, 0.390625_wp, 0.0_wp, "dimethylpyridine")
+   case("dimethylsulfoxide","dmso")
+      data = solvent_data(46.826_wp, 1.417_wp, 0.0_wp, 0.88_wp, 61.78_wp, 0.0_wp, 0.0_wp, "dimethylsulfoxide")
+   case("dioxane") ! no Minnisota database entry
+      data = solvent_data(2.2099_wp, 1.4224_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, "dioxane")
    case("dodecane")
-      data = solvent_data(2.006_wp, 1.4216_wp, 0.0_wp, 0.0_wp, 35.85_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(2.006_wp, 1.4216_wp, 0.0_wp, 0.0_wp, 35.85_wp, 0.0_wp, 0.0_wp, "dodecane")
    case("ethanol")
-      data = solvent_data(24.852_wp, 1.3611_wp, 0.37_wp, 0.48_wp, 31.62_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(24.852_wp, 1.3611_wp, 0.37_wp, 0.48_wp, 31.62_wp, 0.0_wp, 0.0_wp, "ethanol")
    case("ethoxybenzene")
-      data = solvent_data(4.1797_wp, 1.5076_wp, 0.0_wp, 0.32_wp, 46.65_wp, 0.444889_wp, 0.0_wp)
+      data = solvent_data(4.1797_wp, 1.5076_wp, 0.0_wp, 0.32_wp, 46.65_wp, 0.444889_wp, 0.0_wp, "ethoxybenzene")
    case("ethylacetate")
-      data = solvent_data(5.9867_wp, 1.3723_wp, 0.0_wp, 0.45_wp, 33.67_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(5.9867_wp, 1.3723_wp, 0.0_wp, 0.45_wp, 33.67_wp, 0.0_wp, 0.0_wp, "ethylacetate")
    case("ethylbenzene")
-      data = solvent_data(2.4339_wp, 1.4959_wp, 0.0_wp, 0.15_wp, 41.38_wp, 0.5625_wp, 0.0_wp)
+      data = solvent_data(2.4339_wp, 1.4959_wp, 0.0_wp, 0.15_wp, 41.38_wp, 0.5625_wp, 0.0_wp, "ethylbenzene")
    case("fluorobenzene")
-      data = solvent_data(5.42_wp, 1.4684_wp, 0.0_wp, 0.1_wp, 38.37_wp, 0.734449_wp, 0.020449_wp)
+      data = solvent_data(5.42_wp, 1.4684_wp, 0.0_wp, 0.1_wp, 38.37_wp, 0.734449_wp, 0.020449_wp, "fluorobenzene")
    case("fluoroctane")
-      data = solvent_data(3.89_wp, 1.3935_wp, 0.0_wp, 0.1_wp, 33.92_wp, 0.0_wp, 0.012321_wp)
+      data = solvent_data(3.89_wp, 1.3935_wp, 0.0_wp, 0.1_wp, 33.92_wp, 0.0_wp, 0.012321_wp, "fluoroctane")
+   case("furan","furane") ! no Minnisota database entry
+      data = solvent_data(2.953_wp, 1.4214_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, "furane")
    case("heptane")
-      data = solvent_data(1.9113_wp, 1.3878_wp, 0.0_wp, 0.0_wp, 28.28_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(1.9113_wp, 1.3878_wp, 0.0_wp, 0.0_wp, 28.28_wp, 0.0_wp, 0.0_wp, "heptane")
    case("heptanol")
-      data = solvent_data(11.321_wp, 1.4249_wp, 0.37_wp, 0.48_wp, 38.5_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(11.321_wp, 1.4249_wp, 0.37_wp, 0.48_wp, 38.5_wp, 0.0_wp, 0.0_wp, "heptanol")
    case("hexadecane")
-      data = solvent_data(2.0402_wp, 1.4345_wp, 0.0_wp, 0.0_wp, 38.93_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(2.0402_wp, 1.4345_wp, 0.0_wp, 0.0_wp, 38.93_wp, 0.0_wp, 0.0_wp, "hexadecane")
    case("hexadecyliodide")
-      data = solvent_data(3.5338_wp, 1.4806_wp, 0.0_wp, 0.15_wp, 46.48_wp, 0.0_wp, 0.0_wp)
-   case("hexane")
-      data = solvent_data(1.8819_wp, 1.3749_wp, 0.0_wp, 0.0_wp, 25.7495_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(3.5338_wp, 1.4806_wp, 0.0_wp, 0.15_wp, 46.48_wp, 0.0_wp, 0.0_wp, "hexadecyliodide")
+   case("hexane","nhexan","n-hexan","nhexane","n-hexane")
+      data = solvent_data(1.8819_wp, 1.3749_wp, 0.0_wp, 0.0_wp, 25.7495_wp, 0.0_wp, 0.0_wp, "hexane")
    case("hexanol")
-      data = solvent_data(12.5102_wp, 1.4178_wp, 0.37_wp, 0.48_wp, 37.15_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(12.5102_wp, 1.4178_wp, 0.37_wp, 0.48_wp, 37.15_wp, 0.0_wp, 0.0_wp, "hexanol")
    case("iodobenzene")
-      data = solvent_data(4.547_wp, 1.62_wp, 0.0_wp, 0.12_wp, 55.72_wp, 0.734449_wp, 0.0_wp)
+      data = solvent_data(4.547_wp, 1.62_wp, 0.0_wp, 0.12_wp, 55.72_wp, 0.734449_wp, 0.0_wp, "iodobenzene")
    case("isobutanol")
-      data = solvent_data(16.7766_wp, 1.3955_wp, 0.37_wp, 0.48_wp, 32.38_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(16.7766_wp, 1.3955_wp, 0.37_wp, 0.48_wp, 32.38_wp, 0.0_wp, 0.0_wp, "isobutanol")
    case("isooctane")
-      data = solvent_data(1.9358_wp, 1.3915_wp, 0.0_wp, 0.0_wp, 26.38_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(1.9358_wp, 1.3915_wp, 0.0_wp, 0.0_wp, 26.38_wp, 0.0_wp, 0.0_wp, "isooctane")
    case("isopropanol")
-      data = solvent_data(19.2645_wp, 1.3776_wp, 0.33_wp, 0.56_wp, 30.13_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(19.2645_wp, 1.3776_wp, 0.33_wp, 0.56_wp, 30.13_wp, 0.0_wp, 0.0_wp, "isopropanol")
    case("isopropylbenzene")
-      data = solvent_data(2.3712_wp, 1.4915_wp, 0.0_wp, 0.16_wp, 39.85_wp, 0.444889_wp, 0.0_wp)
+      data = solvent_data(2.3712_wp, 1.4915_wp, 0.0_wp, 0.16_wp, 39.85_wp, 0.444889_wp, 0.0_wp, "isopropylbenzene")
    case("mcresol")
-      data = solvent_data(12.44_wp, 1.5438_wp, 0.57_wp, 0.34_wp, 51.37_wp, 0.5625_wp, 0.0_wp)
+      data = solvent_data(12.44_wp, 1.5438_wp, 0.57_wp, 0.34_wp, 51.37_wp, 0.5625_wp, 0.0_wp, "mcresol")
    case("mesitylene")
-      data = solvent_data(2.265_wp, 1.4994_wp, 0.0_wp, 0.19_wp, 39.65_wp, 0.444889_wp, 0.0_wp)
+      data = solvent_data(2.265_wp, 1.4994_wp, 0.0_wp, 0.19_wp, 39.65_wp, 0.444889_wp, 0.0_wp, "mesitylene")
    case("methanol")
-      data = solvent_data(32.613_wp, 1.3288_wp, 0.43_wp, 0.47_wp, 31.77_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(32.613_wp, 1.3288_wp, 0.43_wp, 0.47_wp, 31.77_wp, 0.0_wp, 0.0_wp, "methanol")
    case("methoxyethanol")
-      data = solvent_data(17.2_wp, 1.4024_wp, 0.3_wp, 0.84_wp, 44.39_wp, 0.0_wp, 0.0_wp)
-   case("methylenechloride")
-      data = solvent_data(8.93_wp, 1.4242_wp, 0.1_wp, 0.05_wp, 39.15_wp, 0.0_wp, 0.444889_wp)
+      data = solvent_data(17.2_wp, 1.4024_wp, 0.3_wp, 0.84_wp, 44.39_wp, 0.0_wp, 0.0_wp, "methoxyethanol")
+   case("methylenechloride","dichloromethane","dichlormethane","ch2cl2")
+      data = solvent_data(8.93_wp, 1.4242_wp, 0.1_wp, 0.05_wp, 39.15_wp, 0.0_wp, 0.444889_wp, "methylenechloride")
    case("methylformamide")
-      data = solvent_data(181.5619_wp, 1.4319_wp, 0.4_wp, 0.55_wp, 55.4372_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(181.5619_wp, 1.4319_wp, 0.4_wp, 0.55_wp, 55.4372_wp, 0.0_wp, 0.0_wp, "methylformamide")
    case("nitrobenzene")
-      data = solvent_data(34.8091_wp, 1.5562_wp, 0.0_wp, 0.28_wp, 57.54_wp, 0.444889_wp, 0.0_wp)
+      data = solvent_data(34.8091_wp, 1.5562_wp, 0.0_wp, 0.28_wp, 57.54_wp, 0.444889_wp, 0.0_wp, "nitrobenzene")
    case("nitroethane")
-      data = solvent_data(28.2896_wp, 1.3917_wp, 0.02_wp, 0.33_wp, 46.25_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(28.2896_wp, 1.3917_wp, 0.02_wp, 0.33_wp, 46.25_wp, 0.0_wp, 0.0_wp, "nitroethane")
    case("nitromethane")
-      data = solvent_data(36.5623_wp, 1.3817_wp, 0.06_wp, 0.31_wp, 52.58_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(36.5623_wp, 1.3817_wp, 0.06_wp, 0.31_wp, 52.58_wp, 0.0_wp, 0.0_wp, "nitromethane")
    case("nonane")
-      data = solvent_data(1.9605_wp, 1.4054_wp, 0.0_wp, 0.0_wp, 32.21_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(1.9605_wp, 1.4054_wp, 0.0_wp, 0.0_wp, 32.21_wp, 0.0_wp, 0.0_wp, "nonane")
    case("nonanol")
-      data = solvent_data(8.5991_wp, 1.4333_wp, 0.37_wp, 0.48_wp, 40.14_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(8.5991_wp, 1.4333_wp, 0.37_wp, 0.48_wp, 40.14_wp, 0.0_wp, 0.0_wp, "nonanol")
    case("octane")
-      data = solvent_data(1.9406_wp, 1.3974_wp, 0.0_wp, 0.0_wp, 30.4273_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(1.9406_wp, 1.3974_wp, 0.0_wp, 0.0_wp, 30.4273_wp, 0.0_wp, 0.0_wp, "octane")
    case("octanol")
-      data = solvent_data(9.8629_wp, 1.4295_wp, 0.37_wp, 0.48_wp, 39.01_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(9.8629_wp, 1.4295_wp, 0.37_wp, 0.48_wp, 39.01_wp, 0.0_wp, 0.0_wp, "octanol")
    case("odichlorobenzene")
-      data = solvent_data(9.9949_wp, 1.5515_wp, 0.0_wp, 0.04_wp, 52.72_wp, 0.5625_wp, 0.0625_wp)
+      data = solvent_data(9.9949_wp, 1.5515_wp, 0.0_wp, 0.04_wp, 52.72_wp, 0.5625_wp, 0.0625_wp, "odichlorobenzene")
    case("onitrotoluene")
-      data = solvent_data(25.6692_wp, 1.545_wp, 0.0_wp, 0.27_wp, 59.12_wp, 0.36_wp, 0.0_wp)
+      data = solvent_data(25.6692_wp, 1.545_wp, 0.0_wp, 0.27_wp, 59.12_wp, 0.36_wp, 0.0_wp, "onitrotoluene")
    case("pentadecane")
-      data = solvent_data(2.0333_wp, 1.4315_wp, 0.0_wp, 0.0_wp, 38.34_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(2.0333_wp, 1.4315_wp, 0.0_wp, 0.0_wp, 38.34_wp, 0.0_wp, 0.0_wp, "pentadecane")
    case("pentane")
-      data = solvent_data(1.8371_wp, 1.3575_wp, 0.0_wp, 0.0_wp, 22.3_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(1.8371_wp, 1.3575_wp, 0.0_wp, 0.0_wp, 22.3_wp, 0.0_wp, 0.0_wp, "pentane")
    case("pentanol")
-      data = solvent_data(15.13_wp, 1.4101_wp, 0.37_wp, 0.48_wp, 36.5_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(15.13_wp, 1.4101_wp, 0.37_wp, 0.48_wp, 36.5_wp, 0.0_wp, 0.0_wp, "pentanol")
    case("perfluorobenzene")
-      data = solvent_data(2.029_wp, 1.3777_wp, 0.0_wp, 0.0_wp, 31.74_wp, 0.25_wp, 0.25_wp)
+      data = solvent_data(2.029_wp, 1.3777_wp, 0.0_wp, 0.0_wp, 31.74_wp, 0.25_wp, 0.25_wp, "perfluorobenzene")
+   case("phenol") ! no Minnisota database entry
+      data = solvent_data(12.4_wp, 1.5408_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, "phenol")
    case("phenylether")
-      data = solvent_data(3.73_wp, 1.5787_wp, 0.0_wp, 0.2_wp, 38.5_wp, 0.851929_wp, 0.0_wp)
+      data = solvent_data(3.73_wp, 1.5787_wp, 0.0_wp, 0.2_wp, 38.5_wp, 0.851929_wp, 0.0_wp, "phenylether")
    case("propanol")
-      data = solvent_data(20.5237_wp, 1.385_wp, 0.37_wp, 0.48_wp, 33.57_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(20.5237_wp, 1.385_wp, 0.37_wp, 0.48_wp, 33.57_wp, 0.0_wp, 0.0_wp, "propanol")
    case("pyridine")
-      data = solvent_data(12.9776_wp, 1.5095_wp, 0.0_wp, 0.52_wp, 52.62_wp, 0.693889_wp, 0.0_wp)
+      data = solvent_data(12.9776_wp, 1.5095_wp, 0.0_wp, 0.52_wp, 52.62_wp, 0.693889_wp, 0.0_wp, "pyridine")
    case("secbutanol")
-      data = solvent_data(15.9436_wp, 1.3978_wp, 0.33_wp, 0.56_wp, 32.44_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(15.9436_wp, 1.3978_wp, 0.33_wp, 0.56_wp, 32.44_wp, 0.0_wp, 0.0_wp, "secbutanol")
    case("secbutylbenzene")
-      data = solvent_data(2.3446_wp, 1.4895_wp, 0.0_wp, 0.16_wp, 40.35_wp, 0.36_wp, 0.0_wp)
+      data = solvent_data(2.3446_wp, 1.4895_wp, 0.0_wp, 0.16_wp, 40.35_wp, 0.36_wp, 0.0_wp, "secbutylbenzene")
    case("tbutylbenzene")
-      data = solvent_data(2.3447_wp, 1.4927_wp, 0.0_wp, 0.16_wp, 39.78_wp, 0.36_wp, 0.0_wp)
+      data = solvent_data(2.3447_wp, 1.4927_wp, 0.0_wp, 0.16_wp, 39.78_wp, 0.36_wp, 0.0_wp, "tbutylbenzene")
    case("tetrachloroethene")
-      data = solvent_data(2.268_wp, 1.5053_wp, 0.0_wp, 0.0_wp, 45.19_wp, 0.0_wp, 0.444889_wp)
-   case("tetrahydrofuran")
-      data = solvent_data(7.4257_wp, 1.405_wp, 0.0_wp, 0.48_wp, 39.44_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(2.268_wp, 1.5053_wp, 0.0_wp, 0.0_wp, 45.19_wp, 0.0_wp, 0.444889_wp, "tetrachloroethene")
+   case("tetrahydrofuran","thf")
+      data = solvent_data(7.4257_wp, 1.405_wp, 0.0_wp, 0.48_wp, 39.44_wp, 0.0_wp, 0.0_wp, "tetrahydrofuran")
    case("tetrahydrothiophenedioxide")
-      data = solvent_data(43.9622_wp, 1.4833_wp, 0.0_wp, 0.88_wp, 87.49_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(43.9622_wp, 1.4833_wp, 0.0_wp, 0.88_wp, 87.49_wp, 0.0_wp, 0.0_wp, "tetrahydrothiophenedioxide")
    case("tetralin")
-      data = solvent_data(2.771_wp, 1.5413_wp, 0.0_wp, 0.19_wp, 47.74_wp, 0.36_wp, 0.0_wp)
+      data = solvent_data(2.771_wp, 1.5413_wp, 0.0_wp, 0.19_wp, 47.74_wp, 0.36_wp, 0.0_wp, "tetralin")
    case("toluene")
-      data = solvent_data(2.3741_wp, 1.4961_wp, 0.0_wp, 0.14_wp, 40.2_wp, 0.734449_wp, 0.0_wp)
+      data = solvent_data(2.3741_wp, 1.4961_wp, 0.0_wp, 0.14_wp, 40.2_wp, 0.734449_wp, 0.0_wp, "toluene")
    case("tributylphosphate")
-      data = solvent_data(8.1781_wp, 1.4224_wp, 0.0_wp, 1.21_wp, 27.55_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(8.1781_wp, 1.4224_wp, 0.0_wp, 1.21_wp, 27.55_wp, 0.0_wp, 0.0_wp, "tributylphosphate")
    case("triethylamine")
-      data = solvent_data(2.3832_wp, 1.401_wp, 0.0_wp, 0.79_wp, 29.1_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(2.3832_wp, 1.401_wp, 0.0_wp, 0.79_wp, 29.1_wp, 0.0_wp, 0.0_wp, "triethylamine")
    case("trimethylbenzene")
-      data = solvent_data(2.3653_wp, 1.5048_wp, 0.0_wp, 0.19_wp, 42.03_wp, 0.444889_wp, 0.0_wp)
+      data = solvent_data(2.3653_wp, 1.5048_wp, 0.0_wp, 0.19_wp, 42.03_wp, 0.444889_wp, 0.0_wp, "trimethylbenzene")
    case("undecane")
-      data = solvent_data(1.991_wp, 1.4398_wp, 0.0_wp, 0.0_wp, 34.85_wp, 0.0_wp, 0.0_wp)
-   case("water")
-      data = solvent_data(78.36_wp, 1.3328_wp, 0.82_wp, 0.35_wp, 103.62_wp, 0.0_wp, 0.0_wp)
+      data = solvent_data(1.991_wp, 1.4398_wp, 0.0_wp, 0.0_wp, 34.85_wp, 0.0_wp, 0.0_wp, "undecane")
+   case("water","h2o")
+      data = solvent_data(78.36_wp, 1.3328_wp, 0.82_wp, 0.35_wp, 103.62_wp, 0.0_wp, 0.0_wp, "water")
+   case("woctanol") ! no Minnisota database entry
+      data = solvent_data(9.8629_wp, 1.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, 0.0_wp, "woctanol")
    case("xylene")
-      data = solvent_data(2.3879_wp, 1.4995_wp, 0.0_wp, 0.16_wp, 41.38_wp, 0.5625_wp, 0.0_wp)
+      data = solvent_data(2.3879_wp, 1.4995_wp, 0.0_wp, 0.16_wp, 41.38_wp, 0.5625_wp, 0.0_wp, "xylene")
    end select
 end function get_solvent_data
 
